@@ -6,7 +6,7 @@ use XML::LibXML::LazyBuilder qw{DOM E};
 use Archive::Zip qw{COMPRESSION_DEFLATED};
 use IO::Scalar qw{};
 
-our $VERSION='0.12';
+our $VERSION='0.15';
 
 =head1 NAME
 
@@ -19,6 +19,7 @@ Geo::GoogleEarth::Pluggable - Generates GoogleEarth Documents
   my $folder  =$document->Folder(%data);                #isa Geo::GoogleEarth::Pluggable::Folder
   my $point   =$document->Point(%data);                 #isa Geo::GoogleEarth::Pluggable::Point
   my $netlink =$document->NetworkLink(%data);           #isa Geo::GoogleEarth::Pluggable::NetworkLink
+  my $lookat  =$document->LookAt(%data);                #isa Geo::GoogleEarth::Pluggable::LookAt
   my $style   =$document->Style(%data);                 #isa Geo::GoogleEarth::Pluggable::Style
   print $document->render;
 
@@ -44,16 +45,32 @@ Geo::GoogleEarth::Pluggable (aka Document) is a L<Geo::GoogleEarth::Pluggable::F
 
 =head2 Object Inheritance Graph
 
-  -- Base --- Folder    --- Document
-           |
-           +- Placemark -+- Point
-           |             +- LineString
-           |             +- LinearRing
-           |
-           +- StyleBase -+- Style
-           |             +- StyleMap
-           |
-           +- NetworkLink
+  --- Constructor -+- Base --- Folder    --- Document
+                   |        |
+                   |        +- Placemark -+- Point
+                   |        |             +- LineString
+                   |        |             +- LinearRing
+                   |        |
+                   |        +- StyleBase -+- Style
+                   |        |             +- StyleMap
+                   |        |
+                   |        +- NetworkLink
+                   |
+                   +- LookAt
+
+=head2 Constructors that append to the parent folder object
+
+Folder, NetworkLink, Point, LineString, LinearRing
+
+=head2 Constructors that return objects for future use
+
+LookAt(), Style(), StyleMap()
+
+=head2 Wrappers (what makes it easy)
+
+Style => IconStyle, LineStyle, PolyStyle, LabelStyle, ListStyle
+
+Point => MultiPoint
 
 =head1 USAGE
 
@@ -197,7 +214,7 @@ sub header {
      $data{"content_type"}="application/vnd.google-earth.kml+xml"
        unless defined $data{"content_type"};
   my $header=sprintf("Content-type: %s\n", $data{"content_type"});
-     $header.=sprintf("Content-Disposition: attachment; filename=%s\n",
+     $header.=sprintf(qq{Content-Disposition: attachment; filename="%s";\n},
                          $data{"filename"}) if defined $data{"filename"};
      $header.="\n";
   return $header;
@@ -227,8 +244,6 @@ sub header_kmz {
 
 =over
 
-=item Full support for LookAt
-
 =item Support for default Polygon and Line styles that are nicer than GoogleEarth's
 
 =item Support for DateTime object in the constructor that is promoted to the LookAt object.
