@@ -9,6 +9,7 @@ Geo-GoogleEarth-Pluggable-LineString.pl - Geo::GoogleEarth::Pluggable LineString
 
 =cut
 
+my $type=shift || "kml";
 my $document=Geo::GoogleEarth::Pluggable->new(name=>"My Document");
 my @pt=(
          {lat=>38.1, lon=>-77.1},
@@ -20,4 +21,8 @@ my @pt=(
 $document->LineString(name=>"My LineString", coordinates=>\@pt);
 #use Data::Dumper qw{Dumper};
 #print Dumper($document->structure);
-print $document->render;
+if ($type eq "kmz") {
+  print $document->archive;
+} else {
+  print $document->render;
+}
