@@ -9,8 +9,14 @@ Geo-GoogleEarth-Pluggable-Point.pl - Geo::GoogleEarth::Pluggable Point Example
 
 =cut
 
+my $type=shift || "kml";
 my $document=Geo::GoogleEarth::Pluggable->new(name=>"My Document");
 $document->Point(name=>"My Name", lat=>39, lon=>-77);
 #use Data::Dumper qw{Dumper};
 #print Dumper($document->structure);
-print $document->render;
+
+if ($type eq "kmz") {
+  print $document->archive;
+} else {
+  print $document->render;
+}
